@@ -98,6 +98,8 @@ pub struct ActorResponse {
     pub referrer_address: Option<String>,
     pub participation_reward_amount: Uint128,
     pub referral_reward_amount: Uint128,
+    pub unlocked_participation_reward_amount: Uint128,
+    pub unlocked_referral_reward_amount: Uint128,
     pub cumulative_participation_reward_amount: Uint128,
     pub cumulative_referral_reward_amount: Uint128,
     pub participation_count: u64,
@@ -112,6 +114,8 @@ impl ActorResponse {
             referrer_address: referrer,
             participation_reward_amount: Uint128::zero(),
             referral_reward_amount: Uint128::zero(),
+            unlocked_participation_reward_amount: Uint128::zero(),
+            unlocked_referral_reward_amount: Uint128::zero(),
             cumulative_participation_reward_amount: Uint128::zero(),
             cumulative_referral_reward_amount: Uint128::zero(),
             participation_count: 0,
